@@ -47,8 +47,8 @@ mod.obigt <- function(...) {
   icol <- match(names(args), cnames)
   if(any(is.na(icol))) stop(paste("properties not in thermo$obigt:", paste(names(args)[is.na(icol)], collapse=" ")) )
   # the column numbers for properties that matched after the split
-  icol[icol > 40] <- icol[icol > 40] - 40
-  icol[icol > 20] <- icol[icol > 20] - 20
+  icol[icol > 42] <- icol[icol > 42] - 42
+  icol[icol > 21] <- icol[icol > 21] - 21
   # which species are new and which are old
   inew <- which(is.na(ispecies))
   iold <- which(!is.na(ispecies))
@@ -63,6 +63,8 @@ mod.obigt <- function(...) {
     newrows$state <- thermo$opt$state
     # the formula defaults to the name
     newrows$formula <- args$name[inew]
+    # the units should also be set 20190530
+    newrows$E_units <- thermo$opt$E.units
     # fill in the columns
     newrows[, icol] <- args[inew, ]
     # now check the formulas
@@ -89,7 +91,7 @@ mod.obigt <- function(...) {
     ntotal <- nrow(thermo$obigt)
     ispecies[inew] <- (ntotal-length(inew)+1):ntotal
     # inform user
-    message(paste("mod.obigt: added ", newrows$name, "(", newrows$state, ")", sep="", collapse="\n"))
+    message(paste("mod.obigt: added ", newrows$name, "(", newrows$state, ")", " with energy units of ", newrows$E_units, sep="", collapse="\n"))
   }
   if(length(iold) > 0) {
     # loop over species
@@ -110,7 +112,7 @@ mod.obigt <- function(...) {
   return(ispecies)
 }
 
-add.obigt <- function(file, species=NULL, force=TRUE, E.units="cal") {
+add.obigt <- function(file, species=NULL, force=TRUE) {
   # add/replace entries in thermo$obigt from values saved in a file
   # only replace if force==TRUE
   thermo <- get("thermo", CHNOSZ)
@@ -129,8 +131,10 @@ add.obigt <- function(file, species=NULL, force=TRUE, E.units="cal") {
     if(length(isys)==1) file <- system.file(paste0("extdata/OBIGT/", sysfiles[isys]), package="CHNOSZ")
   }
   # read data from the file
-  # we need explicit colClasses here to avoid automatic detection as character for long numeric values in R 3.1.0  20190302
-  to2 <- read.csv(file, as.is=TRUE, colClasses=c(rep("character", 7), rep("numeric", 13)))
+  to2 <- read.csv(file, as.is=TRUE)
+  # add E_units column if it's missing 20190529
+  if(!"E_units" %in% colnames(to2)) to2 <- data.frame(to2[, 1:7], E_units = "cal", to2[, 8:20], stringsAsFactors = FALSE)
+  Etxt <- paste(unique(to2$E_units), collapse = " and ")
   # load only selected species if requested
   if(!is.null(species)) {
     idat <- match(species, to2$name)
@@ -146,20 +150,6 @@ add.obigt <- function(file, species=NULL, force=TRUE, E.units="cal") {
   does.exist <- id2 %in% id1
   ispecies.exist <- na.omit(match(id2, id1))
   nexist <- sum(does.exist)
-  # convert from J if necessary
-  if(tolower(E.units)=="j") {
-    # loop over each row
-    for(i in 1:nrow(to2)) {
-      # GHS and EOS parameters
-      icol <- (8:18)
-      # if it's aqueous, also include omega
-      if(to2$state[i]=="aq") icol <-(8:19)
-      # don't touch volume (in column 12)
-      icol <- icol[icol!=12]
-      # convert to calories
-      to2[i,icol] <- convert(to2[i,icol],"cal")
-    }
-  }
   # keep track of the species we've added
   inew <- numeric()
   if(force) {
@@ -183,8 +173,9 @@ add.obigt <- function(file, species=NULL, force=TRUE, E.units="cal") {
   thermo$obigt <- to1
   rownames(thermo$obigt) <- 1:nrow(thermo$obigt)
   assign("thermo", thermo, CHNOSZ)
+  # give the user a message
   message("add.obigt: read ", length(does.exist), " rows; made ", 
-    nexist, " replacements, ", nrow(to2), " additions, units = ", E.units)
+    nexist, " replacements, ", nrow(to2), " additions [energy units: ", Etxt, "]")
   message("add.obigt: use obigt() or reset() to restore default database")
   return(invisible(inew))
 }
